@@ -5,14 +5,21 @@ convert the image into the yuv colorspace, drop the u and v components,
 and then average the y component over 4 evenly-spaced rectangles on the
 image dimensions that gives you a floating point number
 """
-
-from typing import Tuple, List, Union
+from typing import Union, List, Tuple
 
 from PIL import Image
+from PIL.Image import open
+
 from luckydonaldUtils.logger import logging
 
 __author__ = 'luckydonald'
 
+from .classes import Intensities, RGB, QuadrantSums
+
+__all__ = [
+    'classes', 'intensities', 'jpg_intensities', 'png_intensities', 'image_intensities',
+    'pixel_array_intensities', 'pixel_bytes_intensities',
+]
 
 logger = logging.getLogger(__name__)
 if __name__ == '__main__':
@@ -20,94 +27,13 @@ if __name__ == '__main__':
 # end if
 
 
-class RGB(object):
-    r: int
-    g: int
-    b: int
-
-    def __init__(
-        self,
-        r: int = 0,
-        g: int = 0,
-        b: int = 0,
-    ):
-        self.r = r
-        self.g = g
-        self.b = b
-    # end def
-
-    def __repr__(self):
-        return f"{self.__class__.__name__}(r={self.r!r}, g={self.g!r}, b={self.b!r})"
-    # end def
-# end class
-
-
-class Sums(object):
-    nw: RGB
-    ne: RGB
-    sw: RGB
-    se: RGB
-
-    # noinspection PyShadowingNames
-    def __init__(
-        self,
-        nw: Union[None, RGB] = None,
-        ne: Union[None, RGB] = None,
-        sw: Union[None, RGB] = None,
-        se: Union[None, RGB] = None,
-    ):
-        if nw is None:
-            nw = RGB()
-        # end if
-        self.nw = nw
-        if ne is None:
-            ne = RGB()
-        # end if
-        self.ne = ne
-        if sw is None:
-            sw = RGB()
-        # end if
-        self.sw = sw
-        if se is None:
-            se = RGB()
-        # end if
-        self.se = se
-    # end def
-
-    def __repr__(self):
-        return f"{self.__class__.__name__}(nw={self.nw!r}, ne={self.ne!r}, sw={self.sw!r}, se={self.se!r})"
-    # end def
-# end class
-
-
-class Luma(object):
-    nw: float
-    ne: float
-    sw: float
-    se: float
-
-    def __init__(self, nw: float, ne: float, sw: float, se: float):
-        self.nw = nw
-        self.ne = ne
-        self.sw = sw
-        self.se = se
-
-    # end def
-
-    def __repr__(self):
-        return f"{self.__class__.__name__}(nw={self.nw!r}, ne={self.ne!r}, sw={self.sw!r}, se={self.se!r})"
-    # end def
-# end class
-
-
-def rgb_sums(img: Image.Image, log_prefix="") -> Sums:
-    width, height = img.size
-    pixels = list(img.getdata())
-    sums = Sums()
+def rgb_sums(pixels: List[int], *, width: int, height: int, log_prefix="") -> QuadrantSums:
+    sums = QuadrantSums()
     log_counter = -1  # more efficient then i % 10 == 0
+    log_interval = height // 10
     for i in range(height):
         log_counter += 1
-        if log_counter == 10:
+        if log_counter == log_interval:
             logger.debug(f'{log_prefix}Processing line {i} of {width}x{height} px image.')
             log_counter = 0
         # end if
@@ -119,7 +45,6 @@ def rgb_sums(img: Image.Image, log_prefix="") -> Sums:
             sw = (i >= height / 2) and (j <= width / 2)
             # noinspection PyShadowingNames
             se = (i >= height / 2) and (j >= width / 2)
-            img.load()
             pixel = pixels[i * width + j]
             r, g, b = pixel[0], pixel[1], pixel[2]
 
@@ -162,12 +87,10 @@ def _calculate_luma(dim: int, sum: RGB):
 # end def
 
 
-def sums_to_luma(sums: Sums, img: Image.Image) -> Luma:
-    width, height = img.size
+def sums_to_luma(sums: QuadrantSums, *, width: int, height: int) -> Intensities:
+    dim = int(max(width * height / 4.0, 1))
 
-    dim = max(width * height / 4.0, 1)
-
-    return Luma(
+    return Intensities(
         nw=_calculate_luma(dim, sums.nw),
         ne=_calculate_luma(dim, sums.ne),
         sw=_calculate_luma(dim, sums.sw),
@@ -176,9 +99,40 @@ def sums_to_luma(sums: Sums, img: Image.Image) -> Luma:
 # end def
 
 
-def rgb_luma_from_filename(filename: str) -> Luma:
-    from PIL.Image import open
+def image_intensities(filename: str) -> Intensities:
     img = open(filename)
-    result = rgb_sums(img)
-    return sums_to_luma(result, img)
+    img.load()
+    width, height = img.size
+    pixels = list(img.getdata())
+    return pixel_array_intensities(pixels, width=width, height=height)
 # end def
+
+
+def pixel_array_intensities(
+    pixels: Union[List[int], List[Tuple[int, int, int]]], *, width: int, height: int
+) -> Intensities:
+    """
+    :param pixels: List of the format [255,255,255, 255,255,255, ...] of pixel values. It has `width x height x 3` elements.
+    :param width: width of the image, needed to figure out the quadrant a pixel is in.
+    :param height: height of the image, needed to figure out the quadrant a pixel is in.
+    :return: The calculated intensities in the quadrants.
+    """
+    result = rgb_sums(pixels, width=width, height=height)
+    return sums_to_luma(result, width=width, height=height)
+# end def
+
+
+def pixel_bytes_intensities(pixels: bytes, *, width: int, height: int) -> Intensities:
+    """
+    :param pixels: Binary representation b'\0x255\0x255\0x255\0x255\0x255\0x255...' of pixel values. It has a length of `width x height x 3`.
+    :param width: width of the image, needed to figure out the quadrant a pixel is in.
+    :param height: height of the image, needed to figure out the quadrant a pixel is in.
+    :return: The calculated intensities in the quadrants.
+    """
+    pixels: List[int] = [x for x in pixels]
+    return pixel_array_intensities(pixels, width=width, height=height)
+# end def
+
+
+jpg_intensities = image_intensities
+png_intensities = image_intensities
