@@ -1,7 +1,8 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+from pathlib import Path
 
-with open('VERSION.txt', 'r') as f:
+with open(str(Path(__file__).parent.absolute() / 'VERSION.txt'), 'r') as f:
     version = f.read().strip()
 # end with
 
